@@ -15,8 +15,10 @@ class ProxyMiddleware(object):
 
     @classmethod
     def from_crawler(cls, crawler): 
-        proxies = [{i:j for i,j in get_config()[proxy].items()} for proxy in get_config().sections() if proxy.startswith("proxy_no")]
-        weights = [i for i in [crawler.settings.get("PROXIES_WEIGHTS",{}).get(proxy) for proxy in get_config().sections() if proxy.startswith("proxy_no")] if i is not None]
+        proxies = [{i:j for i,j in get_config()[proxy].items() if j} for proxy in get_config().sections() 
+                        if proxy.startswith("proxy_no") and get_config()[proxy].get("proxy_user" and "proxy_pass" and "proxy_server")]
+        weights = [i for i in [crawler.settings.get("PROXIES_WEIGHTS",{}).get(proxy) for proxy in get_config().sections() 
+                        if proxy.startswith("proxy_no")] if i is not None]
         s = cls(proxies=proxies,weights=weights)
         crawler.signals.connect(s.spider_opened, signal=signals.spider_opened)
         return s
