@@ -88,6 +88,7 @@ class FactoryMaterialItem(scrapy.Item):
     interior_structure = scrapy.Field() # 内部结构
     installation_type=scrapy.Field()    # 安装类型
     raw_layout_design = scrapy.Field()  # 电路图原链接
+    all_json = scrapy.Field()
 
 
 class FactoryCatergoryItem(scrapy.Item):
@@ -553,6 +554,7 @@ class DetailDataplatformItem(scrapy.Item):
     raw_other_pdf_url = scrapy.Field() # 其他规格书{"名称":"pdf链接"}
     spider_date = scrapy.Field()
     raw_id = scrapy.Field()
+    all_json = scrapy.Field()  # 全部json数据
 
 
 # 热搜
@@ -677,6 +679,31 @@ class SmdITEM(scrapy.Item):
     create_user = scrapy.Field()
     status = scrapy.Field()
 
+class FactorySkuItem(scrapy.Item):
+    table = 'ware_sku_detail' # 测试库bd-crawler 正式库bd-spider
+    def __init__(self, *args, **kwargs):
+        table_params = {'table':kwargs.get('table',self.table)} if not kwargs.get('table_add','') \
+            else {'table':kwargs.get('table',self.table)+kwargs.get('table_add','')}
+        self.__dict__.update(table_params)
+        self._values = {}
+        if args or kwargs and 'table' not in kwargs and 'table_add' not in kwargs:  # avoid creating dict for most common case
+            for k, v in dict(*args, **kwargs).items():
+                self[k] = v
+    ware_id=scrapy.Field()    # 物料id
+    details=scrapy.Field()    # 开源芯片详情
+    brand_id=scrapy.Field()   # 品牌id  int类型<----
+    title=scrapy.Field()      # 型号  <----
+    brand_name=scrapy.Field() # 品牌名称  <----
+    del_flag=scrapy.Field()  # 删除标记
+    creator = scrapy.Field()  # 创建人 <---
+    create_time = scrapy.Field()  # 创建时间 <----
+    sources = scrapy.Field()  # 来源,如原厂manufacturers <----
+    application_manual_url=scrapy.Field()   # 应用手册,xcc链接
+    raw_application_manual_url=scrapy.Field()  #应用手册原始链接
+    video_url=scrapy.Field() # 视频手册 ,xcc链接
+
+
+
 # 物料
 class MaterialItem(scrapy.Item):
     # eg.1: item = MaterialItem(table="ware_detail_dataplatform")
