@@ -14,7 +14,7 @@ from datetime import datetime
 from twisted.internet.threads import deferToThread
 
 class MongodbPipeline(object):
-    def __init__(self,MONGO_HOST,MONGO_PORT,MONGO_PSW,MONGO_USER,MONGO_DB,AUTH_SOURCE,SECTION_SELECT):
+    def __init__(self,MONGO_HOST,MONGO_PORT,MONGO_PSW,MONGO_USER,MONGO_DB,AUTH_SOURCE,TARGET_TABLE,SECTION_SELECT):
         # 链接数据库
         if MONGO_PORT:
             # 兼容之前的settings配置
@@ -32,6 +32,7 @@ class MongodbPipeline(object):
             self.db = self.client.get_database(MONGO_DB, read_preference=ReadPreference.SECONDARY_PREFERRED)
         print("mongo_url:",mongo_url)
         self.section_select = SECTION_SELECT
+        self.target_table = TARGET_TABLE
     @classmethod
     def from_crawler(cls, crawler):
         # 判断运行环境<根据环境变量中是否配置IF_PROD=True,或 测试正式环境settings["IF_PROD"] = True>
@@ -44,10 +45,11 @@ class MongodbPipeline(object):
                    MONGO_USER=get_config().get(section=section_select,option='MONGO_USER',fallback='') or crawler.settings.get('MONGO_USER'),
                    MONGO_DB=get_config().get(section=section_select,option='MONGO_DB',fallback='') or crawler.settings.get('MONGO_DB'),
                    AUTH_SOURCE=get_config().get(section=section_select,option='AUTH_SOURCE',fallback='') or crawler.settings.get('AUTH_SOURCE'),
+                   TARGET_TABLE=get_config().get(section=section_select,option='TARGET_TABLE',fallback='') or crawler.settings.get('TARGET_TABLE',False),
                    SECTION_SELECT = section_select)
 
     def _process_item(self, item, spider):
-        date_time = datetime.now().strftime("_%Y_%m") if self.section_select=='mongo_cfg_prod' else ""
+        date_time = datetime.now().strftime("_%Y_%m") if self.section_select=='mongo_cfg_prod' and not self.target_table else ""
         postItem = dict(item)
         if isinstance(postItem.get("brand_id", None), str) and postItem.get("brand_id").strip() == "":
             raise Exception("brand_id type error")
@@ -93,18 +95,14 @@ class MongodbPipeline(object):
             postItem["p_category_id"] = postItem["p_category_id"].strip()
         if postItem.get("p_category_name", None):  # p_category_name :: 去两端空格
             postItem["p_category_name"] = postItem["p_category_name"].strip()
-        if postItem.get("list_json", None):  # list_json :: json
-            if isinstance(postItem["list_json"], dict):
-                postItem["list_json"] = json.dumps(dict(postItem["list_json"]),ensure_ascii=False)
-        if postItem.get("all_json", None):  # all_json :: json
-            if isinstance(postItem["all_json"], dict):
-                postItem["all_json"] = json.dumps(dict(postItem["all_json"]),ensure_ascii=False)
-        if postItem.get("raw_other_pdf_url", None):  # raw_other_pdf_url :: json
-            if isinstance(postItem["raw_other_pdf_url"], dict):
-                postItem["raw_other_pdf_url"] = json.dumps(dict(postItem["raw_other_pdf_url"]),ensure_ascii=False)
-        if postItem.get("other_pdf_url", None):  # other_pdf_url :: json
-            if isinstance(postItem["other_pdf_url"], dict):
-                postItem["other_pdf_url"] = json.dumps(dict(postItem["other_pdf_url"]),ensure_ascii=False)
+        if isinstance(postItem.get("list_json", None), dict):  # list_json :: json
+            postItem["list_json"] = json.dumps(dict(postItem["list_json"]),ensure_ascii=False)
+        if isinstance(postItem.get("all_json", None), dict):  # all_json :: json
+            postItem["all_json"] = json.dumps(dict(postItem["all_json"]),ensure_ascii=False)
+        if isinstance(postItem.get("raw_other_pdf_url",None), dict):
+            postItem["raw_other_pdf_url"] = json.dumps(dict(postItem["raw_other_pdf_url"]),ensure_ascii=False)
+        if isinstance(postItem.get("other_pdf_url",None), dict):  # other_pdf_url :: json
+            postItem["other_pdf_url"] = json.dumps(dict(postItem["other_pdf_url"]),ensure_ascii=False)
         if postItem.get('create_time', None):  # create_time标准时间格式2022-01-01 00:00:00
             postItem['create_time'] = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
         if postItem.get('spider_time', None):  # spider_time标准时间格式2022-01-01 00:00:00
