@@ -179,7 +179,7 @@ class OssFilesPipeline(MediaPipeline):
         self.files_oss_result_field = settings.get('FILE_PIPE_CONFIG',{}).get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD', self.DEFAULT_FILES_OSS_RESULT_FIELD)
         self.page_logo_text = settings.get('FILE_PIPE_CONFIG',{}).get(self.__class__.__name__,{}).get('PAGE_LOGO_TEXT','')
         self.item_header_dict = settings.get('FILE_PIPE_CONFIG',{}).get(self.__class__.__name__,{}).get('ITEM_HEADER',None)
-        self.files_oss_file = "/".join(["items",datetime.now().strftime("%Y%m"),settings.attributes.get("OSS_FILE")])
+        self.files_oss_file = "/".join(["items",settings.attributes.get("OSS_FILE")])
         self.if_feed = settings.get('FEEDS').attributes
         self.file_pipe_config = file_pipe_config
         self.ext_model = settings.get('EXT_MODEL',False)
@@ -199,7 +199,9 @@ class OssFilesPipeline(MediaPipeline):
         oss_store.check_num = file_pipe_config.get(cls.__name__,{}).get('DEL_PDF_CHECK_NUM',0)
         oss_store.deal_with_pdf = file_pipe_config.get(cls.__name__,{}).get('FILTER_PDF_PAGE',False)
         # 取爬虫源域名结合爬虫名hash成FILES_OSS_FILE做阿里云链接目录
-        start_urls = crawler.spider.start_urls or [i.url for i in crawler.spider.start_requests()] 
+        redis_scheduler_startkey = crawler.spider.redis_key.split(":")[0] if hasattr(crawler.spider,"redis_key") else ""
+        mq_scheduler_queue_startkey = crawler.spider.queue_name if hasattr(crawler.spider,"queue_name") else ""
+        start_urls = crawler.spider.start_urls  or [i.url for i in crawler.spider.start_requests()] or redis_scheduler_startkey or mq_scheduler_queue_startkey
         from urllib import parse
         if start_urls:
             domain = parse.urlparse(start_urls[0]).netloc
@@ -217,9 +219,7 @@ class OssFilesPipeline(MediaPipeline):
             pipe = cls()
         pipe.crawler = crawler
         return pipe
-    # @classmethod
-    # def from_crawler(cls, crawler):
-    #     return cls.from_settings(crawler.settings, crawler)
+    
     def process_item(self, item, spider):
         info = self.spiderinfo
         requests = arg_to_iter(self.get_media_requests(item, info))
@@ -252,11 +252,10 @@ class OssFilesPipeline(MediaPipeline):
             )
             raise FileException('download-error')
 
-        # response.body = content
         if magic.from_buffer(response.body, mime=True).split('/')[-1] == 'pdf':
             retry_invalid_times = 3
             for i in range(retry_invalid_times):
-                # 如果pdf损坏重试
+                # pdf损坏重试
                 try:
                     valid = fitz.Document(stream=response.body, filetype="pdf")
                     if valid.is_repaired:
@@ -268,7 +267,7 @@ class OssFilesPipeline(MediaPipeline):
                     contents = requests.get(response.request.url,headers = headers, timeout=(10,120)).content
                     response = response.replace(body=contents)
                     logging.info(f"Retry {i+1} times , Url is {response.request.url}")
-                    if i+1 >= retry_invalid_times : raise
+                    if i+1 >= retry_invalid_times : raise FileException('download-error')
                 
         media_ext_guss = os.path.splitext(os.path.basename(urlparse(request.url).path))[1]
 
@@ -326,7 +325,7 @@ class OssFilesPipeline(MediaPipeline):
             )
             raise FileException(str(exc))
 
-        return {'url': request.url, 'path': path, 'checksum': checksum, 'status': status}
+        return {'url': request.url, 'path': path, 'checksum': checksum, 'status': status ,"original_link":response.meta["original_link"]}
         
 
     def get_media_requests(self, item, info):
@@ -343,7 +342,7 @@ class OssFilesPipeline(MediaPipeline):
                 if ItemAdapter(item).get(self.file_pipe_config.get(self.__class__.__name__,{}).get("FILES_OSS_URLS_FIELD",self.files_oss_field), '') else []
             def request_add_params(urls):
                 for u in urls:
-                    u = Request(safe_url_string(u))
+                    u = Request(safe_url_string(u),meta={"original_link":u})
                     # 打开爬虫中间件后,_header不为空,取资源链接上一请求的header和referer,
                     # 如果header中包含cookie或响应中包含set-cookie请配置COOKIE_ENABLE=False
                     if item._refer :
@@ -388,14 +387,14 @@ class OssFilesPipeline(MediaPipeline):
         return item
 
     def file_path(self, request, response=None, info=None, *, item=None):
-        media_guid = hashlib.sha1(to_bytes(request.url)).hexdigest()
+        media_guid = hashlib.sha1(response.body).hexdigest()
         media_ext_guss = os.path.splitext(os.path.basename(urlparse(request.url).path))[1]
         if not media_ext_guss and urlparse(request.url).netloc:# 若path为空则视为
             media_ext_guss = 'html'
         with suppress(AttributeError):
             kind = magic.from_buffer(response.body, mime=True).split('/')[-1]
             media_ext = '.'+kind
-        if kind != media_ext_guss.strip(".") and (kind,media_ext_guss.strip(".") not in ['jpg','jpeg'])[1]: 
+        if kind.lower() != media_ext_guss.strip(".").lower() and (kind,media_ext_guss.strip(".") not in ['jpg','jpeg'])[1]: 
             #警告:出现文件流类型和链接拓展名不一致情况
             logging.warning(f"注意:原文件后缀名为( {media_ext_guss.strip('.')} )和判断文件类型( {kind} )不一致 资源链接如下{request.url}")
         if kind =='html': 
@@ -407,12 +406,13 @@ class OssFilesPipeline(MediaPipeline):
         # if self.ext_model :
             # ext_model ::True表示当前情况适合用链接拓展名作为后缀;False表示当前适合用判断文件流来作为后缀
         normal_ext = [
-            'jpg','png','jpeg','webp','svg','gif','tif','bmp',      #图片类
-            'pdf','caj','zip','rar','csv','xlsx','xls','doc','ppt', #文档类
-            'mp4','flv','rm','rmvb','avi','mov','mpeg',             #视频类
-            'mp3','wav','wma'                                       #音频类
+            'jpg','png','jpeg','webp','svg','gif','tif','bmp',                      #图片类
+            'pdf','caj','zip','rar','csv','xlsx','xls','doc','ppt','dwg' ,'dmg',    #文档类
+            'mp4','flv','rm','rmvb','avi','mov','mpeg',                             #视频类
+            'mp3','wav','wma',                                                      #音频类
+            'exe','apk'                                                             #软件类
         ]
-        if kind not in normal_ext and media_ext_guss.strip(".") in normal_ext: #如果判断结果非常见类型,链接拓展为常见类型,取源拓展名
+        if kind not in normal_ext and media_ext_guss.strip("."): #如果判断结果非常见类型,链接拓展为常见类型,取源拓展名
             media_ext = media_ext_guss
         return f'{self.oss_domain}/{self.files_oss_file}/{media_guid}{media_ext}'
 
@@ -424,23 +424,25 @@ class OssFilesPipeline(MediaPipeline):
 class OssPDFPipeline(OssFilesPipeline):
     def transf_img2_pdf(self,img_urls):
         stream_list = list()
-        for img in img_urls.split('|'):
+        img_urls = [i for i in img_urls.split('|') if "pdf" not in i]
+        for img in img_urls:
             stream_list.append(requests.get(img,timeout=10).content)
-        path = ".".join([img.rsplit(".",1)[0],"pdf"])
+        img2pdf_path = ".".join([img.rsplit(".",1)[0],"pdf"])
         buf = io.BytesIO(img2pdf.convert(stream_list))
-        self.store.persist_file(path,buf,info=None)
+        self.store.persist_file(img2pdf_path,buf,info=None)
+        path = "|".join([i for i in img_urls if "pdf" in i].append(img2pdf_path))
         return path
 
     def item_completed(self, results, item, info):
         if self.file_pipe_config.get(self.__class__.__name__,{}).get("RESOURCE_CLASSNAME",'').lower() in item.__class__.__name__.lower():
             with suppress(TypeError):
-                file_urls = '|'.join([x['path'] for ok, x in results if ok])
+                file_urls = '|'.join([x['path'] for ok, x in results if ok and x['path']])
                 if file_urls :
                     if "png" in file_urls or "jpeg" in file_urls :
                         obj_path = self.transf_img2_pdf(file_urls)
                         ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = obj_path
                     else:
-                        ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = '|'.join([x['path'] for ok, x in results if ok])
+                        ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = file_urls
             # TAG: 如果决定资源字段返回为空不存表,修改 FILTER_EMPTY_ITEM = True , 默认false
             with suppress(KeyError):
                 if not item.get(self.file_pipe_config.get(self.__class__.__name__,{}).get("FILES_OSS_RESULT_FIELD",''),"") and self.filter_empty_item:
